summaryrefslogtreecommitdiff
path: root/src/strings/sstring.hpp
diff options
context:
space:
mode:
authorBen Longbons <b.r.longbons@gmail.com>2014-02-08 15:09:25 -0800
committerBen Longbons <b.r.longbons@gmail.com>2014-02-08 16:18:22 -0800
commit730e5dde39333cb2f63c72a7d7152bee5c4dbb05 (patch)
tree510ef3e0ad46ecf1f2bee1fa42f26e6377b51686 /src/strings/sstring.hpp
parent7a15a3efe85837d52d950cc9f895eadcc9eb6be1 (diff)
downloadtmwa-730e5dde39333cb2f63c72a7d7152bee5c4dbb05.tar.gz
tmwa-730e5dde39333cb2f63c72a7d7152bee5c4dbb05.tar.bz2
tmwa-730e5dde39333cb2f63c72a7d7152bee5c4dbb05.tar.xz
tmwa-730e5dde39333cb2f63c72a7d7152bee5c4dbb05.zip
Implement AString
Diffstat (limited to 'src/strings/sstring.hpp')
-rw-r--r--src/strings/sstring.hpp16
1 files changed, 9 insertions, 7 deletions
diff --git a/src/strings/sstring.hpp b/src/strings/sstring.hpp
index 12fb96d..1836d69 100644
--- a/src/strings/sstring.hpp
+++ b/src/strings/sstring.hpp
@@ -1,6 +1,6 @@
#ifndef TMWA_STRINGS_SSTRING_HPP
#define TMWA_STRINGS_SSTRING_HPP
// strings/sstring.hpp - A full slice of an FString.
//
// Copyright © 2013 Ben Longbons <b.r.longbons@gmail.com>
//
@@ -20,19 +20,20 @@
// along with this program. If not, see <http://www.gnu.org/licenses/>.
# include "base.hpp"
-# include "fstring.hpp"
+# include "rstring.hpp"
namespace strings
{
/// An owning string that represents a arbitrary slice of an FString.
/// Not guaranteed to be NUL-terminated.
class SString : public _crtp_string<SString, SString, XPair>
{
- FString _s;
+ RString _s;
size_t _b, _e;
public:
SString();
- SString(FString f);
+ SString(RString f);
+ SString(AString f);
SString(TString t);
//SString(const SString&);
SString(const ZString&);
@@ -45,12 +46,13 @@ namespace strings
SString(const char (&s)[n]);
//template<class It>
//SString(It b, It e) : _s(b, e), _b(0), _e(_s.size()) {}
- SString(FString f, size_t b, size_t e);
+ SString(RString f, size_t b, size_t e);
+ SString(AString f, size_t b, size_t e);
SString(XPair p);
iterator begin() const;
iterator end() const;
- const FString *base() const;
+ const RString *base() const;
};
} // namespace strings
@@ -1,6 +1,6 @@
#ifndef TMWA_STRINGS_SSTRING_HPP
#define TMWA_STRINGS_SSTRING_HPP
-// strings/sstring.hpp - A full slice of an FString.
+// strings/sstring.hpp - A full slice of an RString.
//
// Copyright © 2013 Ben Longbons <b.r.longbons@gmail.com>
@@ -20,19 +20,20 @@
namespace strings
{
- /// An owning string that represents a arbitrary slice of an FString.
+ /// An owning string that represents a arbitrary slice of an RString.
/// Not guaranteed to be NUL-terminated.
class SString : public _crtp_string<SString, SString, XPair>